@@ -5,7 +5,7 @@ L1norm <- function(F,G, eps = 1e-6) {
         n <- length(xk)
         if(!all.equal(F(xk[1] - eps), G(xk[1] - eps))) stop("F(x[1]-) != G(x[1]-)")
         if(!all.equal(F(xk[n]), G(xk[n]))) stop("F(x[n]) != G(x[n])")
-        dy <- (abs(F(xk) - G(xk)))[-length(xk)]
+        dy <- (abs(F(xk) - G(xk)))[-n]
         dx <- diff(xk)
         sum(dy * dx)
         }
